# import packageName.faces as faces
import facedbook.faces as faces
import facedbook.stories as stories
import facedbook.feelings as feelings
import facedbook.encoder as encoder


def main():
    # print(
    #     faces.replace_with_faces(
    #         'All team members must have visibly contributed to the code using their own git & GitHub accounts in order to claim that they contributed to the project.'
    #     ))

    # testing face_story
    print("\nspooky story... \n")
    print(stories.face_story(3))
    print("\nLOOK BEHIND YOU...\n")
    print("BOO!\n")

    # Ask the user how they feel and show a related face emoji
    print("\n Feeling Check! \n")
    print("\n How are you feeling today? (happy, sad, mad, soso): \n")
    print(feelings.ask_user_feeling("happy"))

    # testing face_encoder
    print("\nPrinting happy faces...")
    print(encoder.face_encoder("happy", 8))


if __name__ == "__main__":
    # run the main function
    main()



import pytest, random
from src.facedbook import faces
from src.facedbook import stories
from src.facedbook import feelings
from src.facedbook import encoder


# tests for replace_with_faces()
def test_replace_with_faces_output():  # ensure it returns a single string
    replaced = faces.replace_with_faces("This is a test for the function.")
    assert isinstance(
        replaced, str
    ), f"Expected replace_with_faces() to return a single string. However, it returned {replaced}."


def test_empty_string():  # ensure it handles empty strings
    assert faces.replace_with_faces("") == "Please enter a sentence"


def test_replacing_one_word(
):  # ensure it replaces at least one word with a face
    sentence = "This is a test for the function."
    result = faces.replace_with_faces(sentence)
    assert result != sentence


def test_randomness_with_seed():  #  ensure random function works as expected
    sentence = "This is a test for the function."

    random.seed(8)
    res1 = faces.replace_with_faces(sentence)
    random.seed(8)
    res2 = faces.replace_with_faces(sentence)

    assert res1 == res2

    random.seed(28)  # Change seed, expecting a different result
    res3 = faces.replace_with_faces(sentence)

    assert res1 != res3


# tests for face_story()
def test_face_story_basic():  # ensure it returns a string of 3 lines
    story = stories.face_story(3)
    assert isinstance(story, str)
    assert len(story.split("\n")) == 3


def test_face_story_empty():  # ensure it returns empty string
    story = stories.face_story(0)
    assert story == ""

def test_face_story_large_input(): # ensure it returns a string of large inputs
    story = stories.face_story(10)
    assert isinstance(story, str)
    assert len(story.split("\n")) == 10


def test_face_story_negative():  # ensure it handles negative numbers
    story = stories.face_story(-5)
    assert story == ""


def test_face_story_type_error(
):  # ensure it sends an error for non-int values
    with pytest.raises(TypeError):
        stories.face_story("five")


# tests for ask_user_feeling()


# tests for face_encoder()
def test_face_encoder_output():
    """
    Checks that face_encoder() returns a string of the correct number of faces.
    """
    for num in range(1, 11):
        faces = encoder.face_encoder("happy", num)
        count = len(faces.split("\n"))
        assert isinstance(
            faces, str
        ), f"Expected face_encoder() to return a string. However, it returned {faces}."
        assert count == num, f"Expected face_encoder() to return the correct number of faces. However, it returned {count} faces."


def test_face_encoder_no_faces():
    """
    Checks that face_encoder() returns an empty string when asked for 0 faces.
    """
    faces = encoder.face_encoder("happy", 0)
    assert isinstance(
        faces, str
    ), f"Expected face_encoder() to return a string. However, it returned {faces}."
    assert faces == "", f"Expected face_encoder() to return an empty string. However, it returned {faces}."


def test_face_encoder_max_number():
    """
    Checks that face_encoder() returns an error message for the number of faces limit, which is a string.
    """
    faces = encoder.face_encoder("happy", 11)
    assert isinstance(
        faces, str
    ), f"Expected face_encoder() to return an error message as a string. However, it returned {faces}."
    assert faces == "error: the maximum number of faces is 10", f"Expected face_encoder() to output an error message. However, it outputted {faces}."


def test_face_encoder_invalid_word():
    """
    Checks that face_encoder() returns an error message for a word not found, which is a string.
    """
    faces = encoder.face_encoder("hello", 1)
    assert isinstance(
        faces, str
    ), f"Expected face_encoder() to return an error message as a string. However, it returned {faces}."
    assert faces == "error: face cannot be found for this word", f"Expected face_encoder() to output an error message. However, it outputted {faces}."

def test_face_encoder_case():
    """
    Checks that face_encoder() returns the same output with lowercase and uppercase input (case insensitivity)
    """
    faces_upper = encoder.face_encoder("HAPPY", 3)
    faces_lower = encoder.face_encoder("happy", 3)
    assert faces_upper == faces_lower, f"Expected face_encoder() to have the same output for both lowercase and uppercase word input. Lowercase input outputted {faces_lower} , while uppercase input outputted {faces_upper}."
    


import random


# function to create a random scary story based on the inputted number of sentences
def face_story(n: int = 3) -> str:

    faces = {
        0: "(ノωヽ)",
        1: "(／。＼)",
        2: "(ﾉ_ヽ)",
        3: "..・ヾ(。＞＜)シ",
        4: "(″ロ゛)",
        5: "(;;;*_*)",
        6: "(・人・)",
        7: "＼(〇_ｏ)／",
        8: "(/ω＼)",
        9: "(/_＼)",
        10: "〜(ᗒᗣᗕ)〜",
        11: "Σ(°△°|||)︴",
        12: "(((＞＜)))",
        13: "＼(º □ º l|l)/",
        14: "〣( ºΔº )〣",
        15: "( ꩜ ᯅ ꩜;)⁭ ⁭",
        16: "＼(˚☐˚”)/ ",
        17: "ヾ(｡ꏿ﹏ꏿ)ﾉﾞ",
        18: "(つ﹏⊂)", 
        19: "(ᗒᗣᗕ)՞", 
        20: "ε=ε=(っ*´□`)っ",
        21: "(ｼ;ﾟДﾟ)ｼ",
        22: "(ò_ó╬)",
        23: "(☉_☉’)",
        24: "٩(ര̀ᴗര́)و"
    }

    actions = {
        0: "saw something move in the shadows behind",
        1: "felt an eerie presence near",
        2: "heard whispers coming from",
        3: "was followed by",
        4: "screamed as they saw",
        5: "was chased through the woods by",
        6: "vanished mysteriously after meeting",
        7: "saw glowing red eyes next to",
        8: "was trapped in a haunted house with",
        9: "heard footsteps behind them, but only saw",
        10: "saw their reflection turn into",
        11: "had their candle flicker out near",
        12: "felt icy fingers brush their shoulder from",
        13: "couldn't escape the nightmare of",
        14: "was dragged into the darkness by",
        15: "found an ancient book that summoned",
        16: "was warned in a dream about",
        17: "woke up to find",
        18: "saw a shadow move when looking at",
        19: "was cursed by", 
        20: "heard an echo in a low, quiet voice by", 
        21: "was awakened by scratching sounds made by",
        22: "was frozen in place as he heard raspy breathing from",
        23: "felt a pair of ice cold hands wrap around them from", 
        24: "watched helplessly as the shadows swallowed",
        25: "heard their own voice calling them from the darkness near", 
        26: "watched in horror as their door slowly creaked open, revealing",
        27: "was pulled under the bed by something that looked like",
        28: "felt the temperature drop suddenly as they passed",
        29: "screamed in panic as he was being chased by"
    }

    story = []
    for _ in range(n):
        face1 = faces[random.randint(0, len(faces) - 1)]
        face2 = faces[random.randint(0, len(faces) - 1)]
        action = actions[random.randint(0, len(actions) - 1)]

        sentence = f"{face1} {action} {face2}."
        story.append(sentence)

    return "\n".join(story)